mPhen.defineOptions: Defines and modifies options.

View source: R/mPhen.R

mPhen.defineOptionsR Documentation

Defines and modifies options.

Description

This reads options from the command-line, if provided. Also it can replace references to system variables in option values, such as '*' or WORK, with fully qualified values. Also translates coordinates which use Gb, Mb, Kb to integer values. All defined options of the form mPhen.xxx are examined and modified.

Usage

mPhen.defineOptions(file = NULL, getOptionsFromCommandLine = TRUE)

Arguments

file

specified if the options are in a script file and not set manually

getOptionsFromCommandLine

If running from a script using command Rscript, then this will read in command line options, such as \'–mPhen.logp=FALSE\'

Value

None


MultiPhen documentation built on March 17, 2026, 9:07 a.m.