snps.imputed: Imputed SNP dataset

snps.imputedR Documentation

Imputed SNP dataset

Description

A toy dataset of three imputed SNP, for 150 individuals. For each individuals, and for each SNP, the first column is the probability of a minor allele homozygote genotype (genotype “0”), the second column is the probability of an heterozygote genotype (genotype “1”) and the third and last column is the probability of a major allele homozygote (genotype “2”).

Usage

data(snps.imputed)

Format

A matrix of 150 rows and nine columns.

Examples

data(snps.imputed)

MultiPhen documentation built on March 17, 2026, 9:07 a.m.